@@ -2,6 +2,8 @@ import hashlib
 import inspect
 import json
 import re
+import sys
+import typing
 import urllib.parse
 from abc import ABCMeta
 from collections import OrderedDict, defaultdict
@@ -18,9 +20,10 @@ from django.urls.resolvers import (  # type: ignore
     _PATH_PARAMETER_COMPONENT_RE, RegexPattern, Resolver404, RoutePattern, URLPattern, URLResolver,
     get_resolver,
 )
-from django.utils.functional import Promise
+from django.utils.functional import Promise, cached_property
 from django.utils.module_loading import import_string
 from rest_framework import exceptions, fields, mixins, serializers, versioning
+from rest_framework.settings import api_settings
 from rest_framework.test import APIRequestFactory
 from rest_framework.utils.mediatypes import _MediaType
 from uritemplate import URITemplate
@@ -157,11 +160,13 @@ def build_basic_type(obj):
         return dict(OPENAPI_TYPE_MAPPING[OpenApiTypes.STR])
 
 
-def build_array_type(schema):
-    return {
-        'type': 'array',
-        'items': schema,
-    }
+def build_array_type(schema, min_length=None, max_length=None):
+    schema = {'type': 'array', 'items': schema}
+    if min_length is not None:
+        schema['minLength'] = min_length
+    if max_length is not None:
+        schema['maxLength'] = max_length
+    return schema
 
 
 def build_object_type(
@@ -302,6 +307,8 @@ def _follow_field_source(model, path: List[str]):
         # end of traversal
         if isinstance(field_or_property, property):
             return field_or_property.fget
+        elif isinstance(field_or_property, cached_property):
+            return field_or_property.func
         elif callable(field_or_property):
             return field_or_property
         else:
@@ -563,6 +570,9 @@ def resolve_regex_path_parameter(path_regex, variable, available_formats):
         elif converter == 'drf_format_suffix':
             enum_values = [f'.{suffix}' for suffix in available_formats]
 
+        if api_settings.SCHEMA_COERCE_PATH_PK and parameter == 'pk':
+            parameter = 'id'
+
         if parameter == variable and converter in DJANGO_PATH_CONVERTER_MAPPING:
             return build_parameter_type(
                 name=parameter,
@@ -722,3 +732,71 @@ def set_query_parameters(url, **kwargs) -> str:
     query = {k: v for k, v in kwargs.items() if v is not None}
     query = urllib.parse.urlencode(query, doseq=True)
     return urllib.parse.urlunparse((scheme, netloc, path, params, query, fragment))
+
+
+def get_relative_url(url: str) -> str:
+    scheme, netloc, path, params, query, fragment = urllib.parse.urlparse(url)
+    return urllib.parse.urlunparse(('', '', path, params, query, fragment))
+
+
+def _get_type_hint_origin(hint):
+    """ graceful fallback for py 3.8 typing functionality """
+    if sys.version_info >= (3, 8):
+        return typing.get_origin(hint), typing.get_args(hint)
+    else:
+        origin = getattr(hint, '__origin__', None)
+        args = getattr(hint, '__args__', None)
+        origin = {
+            typing.List: list,
+            typing.Dict: dict,
+            typing.Tuple: tuple,
+            typing.Set: set,
+            typing.FrozenSet: frozenset
+        }.get(origin, origin)
+        return origin, args
+
+
+def resolve_type_hint(hint):
+    """ resolve return value type hints to schema """
+    origin, args = _get_type_hint_origin(hint)
+
+    if origin is None and is_basic_type(hint, allow_none=False):
+        return build_basic_type(hint)
+    elif origin is list or hint is list:
+        return build_array_type(build_basic_type(args[0] if args else OpenApiTypes.OBJECT))
+    elif origin is tuple:
+        return build_array_type(
+            schema=build_basic_type(args[0]),
+            max_length=len(args),
+            min_length=len(args),
+        )
+    elif origin is dict or origin is defaultdict or origin is OrderedDict:
+        schema = build_basic_type(OpenApiTypes.OBJECT)
+        if args[1] is not typing.Any:
+            schema['additionalProperties'] = resolve_type_hint(args[1])
+        return schema
+    elif origin is set:
+        return build_array_type(resolve_type_hint(args[0]))
+    elif origin is frozenset:
+        return build_array_type(resolve_type_hint(args[0]))
+    elif hasattr(typing, 'Literal') and origin is typing.Literal:
+        # python >= 3.8
+        schema = {'enum': list(args)}
+        if all(type(args[0]) is type(choice) for choice in args):
+            schema.update(build_basic_type(type(args[0])))
+        return schema
+    elif hasattr(typing, 'TypedDict') and isinstance(hint, typing._TypedDictMeta):
+        return build_object_type(
+            properties={
+                k: resolve_type_hint(v) for k, v in typing.get_type_hints(hint).items()
+            }
+        )
+    elif origin is typing.Union and len(args) == 2 and isinstance(None, args[1]):
+        # Optional[*] is resolved to Union[*, None]
+        schema = resolve_type_hint(args[0])
+        schema['nullable'] = True
+        return schema
+    elif origin is typing.Union:
+        return {'oneOf': [resolve_type_hint(arg) for arg in args]}
+    else:
+        raise UnableToProceedError()
