@@ -19,6 +19,7 @@ class OpenApiTypes(enum.Enum):
     STR = enum.auto()
     BYTE = enum.auto()  # base64 encoded
     BINARY = enum.auto()
+    PASSWORD = enum.auto()
     INT = enum.auto()
     UUID = enum.auto()
     URI = enum.auto()
@@ -41,6 +42,7 @@ OPENAPI_TYPE_MAPPING = {
     OpenApiTypes.STR: {'type': 'string'},
     OpenApiTypes.BYTE: {'type': 'string', 'format': 'byte'},
     OpenApiTypes.BINARY: {'type': 'string', 'format': 'binary'},
+    OpenApiTypes.PASSWORD: {'type': 'string', 'format': 'password'},
     OpenApiTypes.INT: {'type': 'integer'},
     OpenApiTypes.UUID: {'type': 'string', 'format': 'uuid'},
     OpenApiTypes.URI: {'type': 'string', 'format': 'uri'},
