@@ -1,3 +1,4 @@
+import functools
 import inspect
 from typing import Dict, List, Type, Union
 
@@ -5,6 +6,8 @@ from rest_framework.fields import empty
 from rest_framework.serializers import Serializer
 from rest_framework.settings import api_settings
 
+from drf_spectacular.drainage import error, get_view_methods, set_override, warn
+
 SerializerType = Union[Serializer, Type[Serializer]]
 
 
@@ -91,8 +94,8 @@ def extend_schema(
         versions=None,
 ):
     """
-    decorator for the "view" kind. partially or completely overrides what would be
-    generated by drf-spectacular.
+    decorator mainly for the "view" method kind. partially or completely overrides
+    what would be generated by drf-spectacular.
 
     :param operation_id: replaces the auto-generated operation_id. make sure there
         are no naming collisions.
@@ -122,7 +125,7 @@ def extend_schema(
     """
     def decorator(f):
         BaseSchema = (
-            # explicit manually set schema
+            # explicit manually set schema or previous view annotation
             getattr(f, 'schema', None)
             # previously set schema with @extend_schema on views methods
             or getattr(f, 'kwargs', {}).get('schema', None)
@@ -200,9 +203,23 @@ def extend_schema(
                 return super().get_tags()
 
         if inspect.isclass(f):
-            class ExtendedView(f):
-                schema = ExtendedSchema()
-            return ExtendedView
+            # either direct decoration of views, or unpacked @api_view from OpenApiViewExtension
+            if operation_id is not None or operation is not None:
+                error(
+                    f'using @extend_schema on viewset class {f.__name__} with parameters '
+                    f'operation_id or operation will most likely result in a broken schema.'
+                )
+            # reorder schema class MRO so that view method annotation takes precedence
+            # over view class annotation. only relevant if there is a method annotation
+            for view_method in get_view_methods(view=f, schema=BaseSchema):
+                if 'schema' in getattr(view_method, 'kwargs', {}):
+                    view_method.kwargs['schema'] = type(
+                        'ExtendedMetaSchema', (view_method.kwargs['schema'], ExtendedSchema), {}
+                    )
+            # persist schema on class to provide annotation to derived view methods.
+            # the second purpose is to serve as base for view multi-annotation
+            f.schema = ExtendedSchema()
+            return f
         elif callable(f) and hasattr(f, 'cls'):
             # 'cls' attr signals that as_view() was called, which only applies to @api_view.
             # keep a "unused" schema reference at root level for multi annotation convenience.
@@ -241,9 +258,7 @@ def extend_schema_field(field):
     """
 
     def decorator(f):
-        if not hasattr(f, '_spectacular_annotation'):
-            f._spectacular_annotation = {}
-        f._spectacular_annotation['field'] = field
+        set_override(f, 'field', field)
         return f
 
     return decorator
@@ -260,17 +275,56 @@ def extend_schema_serializer(many=None, exclude_fields=None):
         schema. fields will still be exposed through the API.
     """
     def decorator(klass):
-        if not hasattr(klass, '_spectacular_annotation'):
-            klass._spectacular_annotation = {}
         if many is not None:
-            klass._spectacular_annotation['many'] = many
+            set_override(klass, 'many', many)
         if exclude_fields:
-            klass._spectacular_annotation['exclude_fields'] = exclude_fields
+            set_override(klass, 'exclude_fields', exclude_fields)
         return klass
 
     return decorator
 
 
+def extend_schema_view(**kwargs):
+    """
+    Convenience decorator for the "view" kind. Intended for annotating derived view methods that
+    are are not directly present in the view (usually methods like ``list`` or ``retrieve``).
+    Spares you from overriding methods like ``list``, only to perform a super call in the body
+    so that you have have something to attach ``@extend_schema`` to.
+
+    :param kwargs: method names as argument names and ``extend_schema()`` calls as values
+    """
+    def wrapping_decorator(method_decorator, method):
+        @method_decorator
+        @functools.wraps(method)
+        def wrapped_method(self, request, *args, **kwargs):
+            return method(self, request, *args, **kwargs)
+
+        return wrapped_method
+
+    def decorator(view):
+        view_methods = {m.__name__: m for m in get_view_methods(view)}
+
+        for method_name, method_decorator in kwargs.items():
+            if method_name not in view_methods:
+                warn(
+                    f'@extend_schema_view argument "{method_name}" was not found on view '
+                    f'{view.__name__}. method override for "{method_name}" will be ignored.'
+                )
+                continue
+
+            method = view_methods[method_name]
+            # the context of derived methods must not be altered, as it belongs to the other
+            # class. create a new context via the wrapping_decorator so the schema can be safely
+            # stored in the wrapped_method. methods belonging to the view can be safely altered.
+            if method_name in view.__dict__:
+                method_decorator(method)
+            else:
+                setattr(view, method_name, wrapping_decorator(method_decorator, method))
+        return view
+
+    return decorator
+
+
 def inline_serializer(name: str, fields: Dict[str, object], **kwargs) -> SerializerType:
     """
     A helper function to create an inline serializer. Primary use is with `@extend_schema`,
